<?php
/**
 * An interface for requests
 *
 * @author		Roland Haeder <webmaster@mxchange.org>
 * @version		0.0.0
 * @copyright	Copyright(c) 2007, 2008 Roland Haeder, this is free software
 * @license		GNU GPL 3.0 or any newer version
 * @link 		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
interface Requestable extends FrameworkInterface {
	/**
	 * Prepares the HTTP request data for usage by currently copying
	 * $_REQUEST into a private attribute. Later on we can add more
	 * things for initialization here.
	 *
	 * @return	void
	 */
	function prepareRequestData ();

	/**
	 * Checks wether a request element is set
	 * @param	$element	Name of the request element we want to check
	 * @return	$isSet		Wether the request element is set
	 * @throws	MissingArrayElementsException	Thrown if a request element is not set
	 */
	function isRequestElementSet ($element);

	/**
	 * Getter for request element or 'null' if the element was not found
	 *
	 * @param	$element	Name of the request element we want to check
	 * @return	$value		Value of the found request element or 'null' if the
	 *						element was not found
	 */
	function getRequestElement ($element);

	/**
	 * Wrapper method for array_key() function for the request data array
	 *
	 * @return	$array	An array containing all array keys to return
	 */
	function getParameterNames ();

	/**
	 * Getter for a header element or 'null' if the header was not found
	 *
	 * @param	$headerName		Name of the header
	 * @return	$headerValue	Value of the header or 'null' if not found
	 */
	function getHeader ($headerName);

	/**
	 * Sets wether the request was valid (default: true)
	 *
	 * @param	$isValid		Wether the request is valid
	 * @return	void
	 */
	function requestIsValid ($isValid = true);
}

//
?>
