<?php
/**
 * BZIP2 compression and decompression class
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright(c) 2007, 2008 Roland Haeder, this is free software
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class Bzip2Compressor extends BaseFrameworkSystem implements Compressor {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor!
		parent::__construct(__CLASS__);

		// Set description
		$this->setObjectDescription("BZIP2 compressor");

		// Create an unique ID
		$this->createUniqueID();
	}

	/**
	 * Create a new compressor channel based a given compression handler
	 *
	 * @return	$cInstance	An instance of this class
	 */
	public final static function createBzip2Compressor () {
		// Get new instance
		if ((function_exists('bzcompress')) && (function_exists('bzdecompress'))) {
			// Compressor can maybe be used
			$cInstance = new Bzip2Compressor();
		} else {
			// Routines not found!
			$cInstance = null;
		}

		// Return the compressor instance
		return $cInstance;
	}

	/**
	 * BZIP2 compression stream
	 *
	 * @param		$streamData			Mixed non-object stream data
	 * @return	$streamData			The compressed stream data	
	 * @throws	InvalidObjectException	If the stream is an object
	 */
	public function compressStream ($streamData) {
		if (is_object($streamData)) {
			// Throw an exception
			throw new InvalidObjectException($streamData, self::EXCEPTION_UNEXPECTED_OBJECT);
		}

		// Return the compressed stream
		return bzcompress($streamData, 1);
	}

	/**
	 * BZIP2 decompression stream
	 *
	 * @param		$streamData			Mixed non-object stream data
	 * @return	$streamData			The decompressed stream data	
	 * @throws	InvalidObjectException	If the stream is an object
	 */
	public function decompressStream ($streamData) {
		if (is_object($streamData)) {
			// Throw an exception
			throw new InvalidObjectException($streamData, self::EXCEPTION_UNEXPECTED_OBJECT);
		}

		// Return the decompressed stream
		return bzdecompress($streamData);
	}

	/**
	 * Getter for the file extension of this compressor
	 *
	 * @return	$string	Returns always "bz2"
	 */
	public final function getCompressorExtension () {
		return "bz2";
	}
}

// [EOF]
?>
